==> bibledit_1.7.orig.tar.gz: bibledit-1.7/src/dialogprintorderportion.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#ifndef INCLUDED_DIALOGPRINT_ORDER_PORTION_H
#define INCLUDED_DIALOGPRINT_ORDER_PORTION_H


#include <gtk/gtk.h>
#include "scripture.h"
#include "ustring.h"
#include "configuration.h"


class PrintOrderPortionDialog
{
public:
  PrintOrderPortionDialog (Scripture *scripture, Configuration * configuration);
  virtual ~PrintOrderPortionDialog ();
  virtual int run ();
protected:
  GtkWidget *printorderportiondialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *scrolledwindow1;
  GtkWidget *treeview1;
  GtkWidget *table1;
  GtkWidget *button_ot;
  GtkWidget *alignment1;
  GtkWidget *hbox3;
  GtkWidget *image1;
  GtkWidget *label5;
  GtkWidget *button_nt;
  GtkWidget *alignment2;
  GtkWidget *hbox4;
  GtkWidget *image2;
  GtkWidget *label6;
  GtkWidget *button_all;
  GtkWidget *alignment3;
  GtkWidget *hbox5;
  GtkWidget *image3;
  GtkWidget *label7;
  GtkWidget *button_current;
  GtkWidget *alignment4;
  GtkWidget *hbox6;
  GtkWidget *image4;
  GtkWidget *label8;
  GtkWidget *button_standard_order;
  GtkWidget *alignment5;
  GtkWidget *hbox8;
  GtkWidget *image5;
  GtkWidget *label9;
  GtkWidget *button_portion;
  GtkWidget *alignment6;
  GtkWidget *hbox9;
  GtkWidget *image6;
  GtkWidget *label10;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_okbutton ();
  static void on_button_ot_clicked (GtkButton *button, gpointer user_data);
  virtual void on_button_ot ();
  static void on_button_nt_clicked (GtkButton *button, gpointer user_data);
  virtual void on_button_nt ();
  static void on_button_all_clicked (GtkButton *button, gpointer user_data);
  virtual void on_button_all ();
  static void on_button_current_clicked (GtkButton *button, gpointer user_data);
  virtual void on_button_current ();
  static void on_button_standard_order_clicked (GtkButton *button, gpointer user_data);
  virtual void on_button_standard_order ();
  static void include_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data);
  static void on_button_portion_clicked (GtkButton *button, gpointer user_data);
  virtual void on_button_portion ();
  static void on_treeview1_cursor_changed (GtkTreeView *treeview, gpointer user_data);
  static bool on_timeout (gpointer data);
  virtual void on_treeview1_cursor ();
  virtual bool selection_get (ustring& book, bool& include, ustring& portion);
  virtual void books_include (set<ustring>& books);
private:
  Scripture * myscripture;
  Configuration * myconfiguration;
  GtkListStore *store;
  GtkTreeViewColumn *column1;
  GtkTreeViewColumn *column2;
  GtkTreeViewColumn *column3;
  GtkTreeSelection *select;
};


#endif

==> bibledit_1.9.orig.tar.gz: bibledit-1.9/src/dialogprintorderportion.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#ifndef INCLUDED_DIALOGPRINT_ORDER_PORTION_H
#define INCLUDED_DIALOGPRINT_ORDER_PORTION_H


#include <gtk/gtk.h>
#include "ustring.h"
#include "generalconfig.h"


class PrintOrderPortionDialog
{
public:
  PrintOrderPortionDialog (int dummy);
  ~PrintOrderPortionDialog ();
  int run ();
protected:
  GtkWidget *printorderportiondialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *scrolledwindow1;
  GtkWidget *treeview1;
  GtkWidget *table1;
  GtkWidget *button_ot;
  GtkWidget *alignment1;
  GtkWidget *hbox3;
  GtkWidget *image1;
  GtkWidget *label5;
  GtkWidget *button_nt;
  GtkWidget *alignment2;
  GtkWidget *hbox4;
  GtkWidget *image2;
  GtkWidget *label6;
  GtkWidget *button_all;
  GtkWidget *alignment3;
  GtkWidget *hbox5;
  GtkWidget *image3;
  GtkWidget *label7;
  GtkWidget *button_current;
  GtkWidget *alignment4;
  GtkWidget *hbox6;
  GtkWidget *image4;
  GtkWidget *label8;
  GtkWidget *button_standard_order;
  GtkWidget *alignment5;
  GtkWidget *hbox8;
  GtkWidget *image5;
  GtkWidget *label9;
  GtkWidget *button_portion;
  GtkWidget *alignment6;
  GtkWidget *hbox9;
  GtkWidget *image6;
  GtkWidget *label10;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  void on_okbutton ();
  static void on_button_ot_clicked (GtkButton *button, gpointer user_data);
  void on_button_ot ();
  static void on_button_nt_clicked (GtkButton *button, gpointer user_data);
  void on_button_nt ();
  static void on_button_all_clicked (GtkButton *button, gpointer user_data);
  void on_button_all ();
  static void on_button_current_clicked (GtkButton *button, gpointer user_data);
  void on_button_current ();
  static void on_button_standard_order_clicked (GtkButton *button, gpointer user_data);
  void on_button_standard_order ();
  static void include_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data);
  static void on_button_portion_clicked (GtkButton *button, gpointer user_data);
  void on_button_portion ();
  static void on_treeview1_cursor_changed (GtkTreeView *treeview, gpointer user_data);
  static bool on_timeout (gpointer data);
  void on_treeview1_cursor ();
  bool selection_get (ustring& book, bool& include, ustring& portion);
  void books_include (set<ustring>& books);
private:
  GeneralConfiguration genconfig;
  GtkListStore *store;
  GtkTreeViewColumn *column1;
  GtkTreeViewColumn *column2;
  GtkTreeViewColumn *column3;
  GtkTreeSelection *select;
};


#endif
